<?php

namespace Bydedi\Database\DependencyInjection\Compiler;

use Symfony\Component\DependencyInjection\Reference;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;

/**
 * Class RegisterEventSubscribersPass
 * @package Bydedi\Database\DependencyInjection\Compiler
 */
class RegisterEventSubscribersPass implements CompilerPassInterface
{
    /**
     * @var string
     */
    protected $dispatcherService;

    /**
     * @var string
     */
    protected $subscriberTag;

    /**
     * Constructor.
     *
     * @param string $dispatcherService Service name of the event dispatcher in processed container
     * @param string $subscriberTag     Tag name used for subscribers
     */
    public function __construct($dispatcherService, $subscriberTag)
    {
        $this->dispatcherService = $dispatcherService;
        $this->subscriberTag = $subscriberTag;
    }

    public function process(ContainerBuilder $container)
    {

        if (!$container->findDefinition($this->dispatcherService)) {
            return;
        }

        $taggedSubscribers = $container->findTaggedServiceIds($this->subscriberTag);

        if (empty($taggedSubscribers)) {
            return;
        }

        $evm = $container->findDefinition($this->dispatcherService);

        foreach ($taggedSubscribers as $id => $instance) {
            $evm->addMethodCall('addEventSubscriber', array(new Reference($id)));
        }
    }
}
