<?php

namespace Bydedi\Utils\Excel;

use PHPExcel;
use PHPExcel_Reader_Excel5;
use PHPExcel_Style_Alignment;
use PHPExcel_Style_Border;
use PHPExcel_Style_Fill;

/**
 * Class Excel
 * @package Bydedi\Utils\Excel
 */
class Excel extends PHPExcel
{

    public function send($writer, $filename = 'file.xls')
    {

        header("Pragma: public");
        header("Expires: 0");
        header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
        header("Content-Type: application/force-download");
        header("Content-Type: application/octet-stream");
        header("Content-Type: application/download");
        header("Content-Disposition: attachment;filename=" . $filename);
        header("Content-Transfer-Encoding: binary ");

        $writer->save("php://output");
    }

    public function writeArray($worksheet, $lg, $data)
    {

        $i = 0;
        foreach ($data as $col) {
            $worksheet->setCellValueByColumnAndRow($i, $lg, $col);
            $i++;
        }
    }

    public function setFormat($font="", $align="", $border="", $fill="")
    {


        $arrFont = array();
        $arrAlign = array();
        $arrBorder = array();
        $arrFill = array();
        if (!empty($font)) {
            if (isset($font['color'])) {
                $arrFont = array_merge($arrFont, array('color' => array('rgb' => $font['color'])));
            }
            if (isset($font['bold'])) {
                $arrFont = array_merge($arrFont, array('bold' => $font['bold']));
            }
            if (isset($font['italic'])) {
                $arrFont = array_merge($arrFont, array('italic' => $font['italic']));
            }
            if (isset($font['size'])) {
                $arrFont = array_merge($arrFont, array('size' => $font['size']));
            }
        }

        if (!empty($align)) {
            if (isset($align['h'])) {
                switch ($align['h']) {
                    case 'center':
                        $arrAlign = array_merge($arrAlign, array('horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER));
                        break;
                    default:
                        break;
                }
            }
            if (isset($align['v'])) {
                switch ($align['v']) {
                    case 'top':
                        $arrAlign = array_merge($arrAlign, array('vertical' => PHPExcel_Style_Alignment::VERTICAL_TOP));
                        break;
                    default:
                        break;
                }
            }
        }

        if (!empty($border)) {
            $arrBorder = array(
                'allborders' => array('style' => PHPExcel_Style_Border::BORDER_THIN, 'color' => array('rgb' => $border)),
                //'bottom' => array('style' => PHPExcel_Style_Border::BORDER_THIN, 'color' => array('rgb' => $border)),
                //'left' => array('style' => PHPExcel_Style_Border::BORDER_THIN, 'color' => array('rgb' => $border)),
                //'right' => array('style' => PHPExcel_Style_Border::BORDER_THIN, 'color' => array('rgb' => $border))
            );
        }

        if (!empty($fill)) {
            $arrFill = array('type' => PHPExcel_Style_Fill::FILL_SOLID, 'color' => array('rgb' => $fill));
        }

        // On definit le style des entetes
        $format = array(
            'font' => $arrFont,
            'alignment' => $arrAlign,
            'borders' => $arrBorder,
            'fill' => $arrFill
        );

        return $format;
    }

    public function getCoord($number)
    {

        $tabLetter = array(
            'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z'
        );

        if ($number >= 26) {
            $l1 = floor($number / 26) - 1;
            $l2 = ($number % 26);
            return $tabLetter[$l1] . $tabLetter[$l2];
        } else {
            $l1 = $number;
            return $tabLetter[$l1];
        }
    }

    public function readFile($filename, $sheets = array())
    {

        $objReader = new PHPExcel_Reader_Excel5();
        $objReader->setReadDataOnly(true);          // lis les données du fichier sans prendre en compte le style
        if(!empty($sheets))
            $objReader->setLoadSheetsOnly($sheets);     // specifie les feuilles a parcourir ex : array("Sheet 1", "My special sheet")
        return $objReader->load($filename);

    }
}

